@@ -1,12 +1,25 @@
 package UV::Check;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.000008';
 
 use strict;
 use warnings;
 use Carp ();
+use Exporter qw(import);
 use parent 'UV::Handle';
 
+sub _after_new {
+    my ($self, $args) = @_;
+    $self->_add_event('check', $args->{on_check});
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
+}
+
 sub start {
     my $self = shift;
     if (@_) {
@@ -50,6 +63,7 @@ UV::Check - Check handles in libuv
   my $loop = UV::Loop->new(); # non-default loop
   my $check = UV::Check->new(
     loop => $loop,
+    on_alloc => sub {say "alloc!"},
     on_close => sub {say "close!"},
     on_check => sub {say "check!"},
   );
@@ -103,6 +117,7 @@ following extra methods available.
     # Or tell it what loop to initialize against
     my $check = UV::Check->new(
         loop => $loop,
+        on_alloc => sub {say "alloc!"},
         on_close => sub {say "close!"},
         on_check => sub {say "check!"},
     );
@@ -127,8 +142,6 @@ L<UV::Loop/"default_loop"> is assumed.
 The L<start|http://docs.libuv.org/en/v1.x/check.html#c.uv_check_start> method
 starts the check handle.
 
-Returns the C<$check> instance itself.
-
 =head2 stop
 
     $check->stop();
