@@ -1,6 +1,6 @@
 package UV::Handle;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.000008';
 
 use strict;
 use warnings;
@@ -9,41 +9,96 @@ use Exporter qw(import);
 use UV ();
 use UV::Loop ();
 
-sub _new_args {
-    my ($class, $args) = @ _;
-    my $loop = delete $args->{loop} // UV::Loop->default;
-    return ($loop);
+sub _add_event {
+    my ($self, $event, $cb) = @_;
+    return unless $self && $event && !CORE::ref($event);
+    push @{$self->{_events}}, $event;
+    $self->on($event, $cb);
 }
 
 sub new {
-    my $class = shift;
-    my %args = @_;
+    my $self = bless {}, shift;
+    my $args = UV::_parse_args(@_);
+    $self->{_closed} = 0;
+    $self->{_events} = [qw(alloc close)];
+    $self->on('alloc', $args->{on_alloc});
+    $self->on('close', $args->{on_close});
+    $self->{data} = $args->{data};
 
-    my $self = $class->_new($class->_new_args(\%args));
-    $self->on(($_ =~ m/^on_(.*)/)[0] => delete $args{$_}) for grep { m/^on_/ } keys %args;
-
-    if(%args) {
-        my $code;
-        $code = $self->can("_set_$_") and $self->$code(delete $args{$_}) for keys %args;
-        die "TODO: more args @{[ keys %args ]}" if keys %args;
+    my $loop = $args->{loop} || $args->{single_arg};
+    unless ($loop && UV::Loop::_is_a_loop($loop)) {
+        $loop = UV::Loop->default();
+    }
+    $self->{_loop} = $loop;
+    if ($self->can('_after_new')) {
+        $self->_after_new($args);
     }
-
     return $self;
 }
 
-sub on {
+sub DESTROY {
     my $self = shift;
-    my $method = "_on_" . shift;
-    return $self->$method( @_ );
+    return unless $self->_has_struct();
+    $self->stop() if ($self->can('stop') && !$self->closing() && !$self->closed());
+
+    my $err = do { # catch
+        local $@;
+        eval { $self->_destruct($self->closed()); 1; }; # try
+        $@;
+    };
+    warn $err if $err;
+}
+
+sub active {
+    my $self = shift;
+    return 0 unless $self->_has_struct();
+    return 0 if $self->closed() || $self->closing();
+    my $val = 0;
+    my $err = do { # catch
+        local $@;
+        eval { $val = $self->_active(); 1; }; # try
+        $@;
+    };
+    Carp::croak($err) if $err;
+    return $val;
 }
 
 sub close {
     my $self = shift;
-    $self->on('close', @_) if @_;
+    $self->on('close', @_) if @_; # set the callback ahead of time if exists
+    return unless $self->_has_struct();
 
-    return if $self->closed || $self->closing;
-    $self->stop if $self->can('stop');
-    $self->_close;
+    return if $self->closed() || $self->closing();
+    $self->stop() if $self->can('stop');
+    my $err = do { # catch
+        local $@;
+        eval { $self->_close(); 1; }; # try
+        $@;
+    };
+    Carp::croak($err) if $err;
+}
+
+sub closed { return (shift->{_closed})? 1: 0; }
+
+sub data {
+    my $self = shift;
+    return $self->{data} unless @_;
+    $self->{data} = shift;
+    return $self;
+}
+
+sub loop { return shift->{_loop}; }
+
+sub on {
+    my $self = shift;
+    my $event = lc(shift || '');
+    return $self->{"_on_$event"} unless @_;
+
+    if ($event && grep {$event eq $_} @{$self->{_events}}) {
+        my $cb = ($_[0] && CORE::ref($_[0]) eq 'CODE')? shift: undef;
+        $self->{"_on_$event"} = $cb;
+    }
+    return $self;
 }
 
 1;
@@ -122,6 +177,19 @@ from those sub-classes.
 
 L<UV::Handle> makes the following extra events available.
 
+=head2 alloc
+
+    $handle->on("alloc", sub { say "We are allocating!"});
+    $handle->on("alloc", sub {
+        # the handle instance this event fired on and the buffer size in use
+        my ($invocant, $buffer_size) = @_;
+        say "A buffer of size $buffer_size was just allocated for us!";
+    });
+
+The L<alloc|http://docs.libuv.org/en/v1.x/handle.html#c.uv_alloc_cb> callback
+fires when a C<< $handle->read_start() >> or C<< $handle->recv_start() >>
+method gets called.
+
 =head2 close
 
     $handle->on("close", sub { say "We are closing!"});
@@ -229,6 +297,15 @@ method returns non-zero if the handle is closing or closed, zero otherwise.
 B<* Note:> This function should only be used between the initialization of the
 handle and the arrival of the C<close> callback.
 
+=head2 has_ref
+
+    my $int = $handle->has_ref();
+
+The L<has_ref|http://docs.libuv.org/en/v1.x/handle.html#c.uv_has_ref>
+method returns non-zero if the handle is referenced, zero otherwise.
+
+See L<Reference Counting|http://docs.libuv.org/en/v1.x/handle.html#refcount>.
+
 =head2 on
 
     # set a close event callback to print the handle's data attribute
@@ -245,6 +322,28 @@ handle and the arrival of the C<close> callback.
 The C<on> method allows you to subscribe to L<UV::Handle/"EVENTS"> emitted by
 any UV::Handle or subclass.
 
+=head2 ref
+
+    $handle->ref();
+
+The L<ref|http://docs.libuv.org/en/v1.x/handle.html#c.uv_ref>
+method references the given handle. References are idempotent, that is, if a
+handle is already referenced, then calling this function again will have no
+effect.
+
+See L<Reference Counting|http://docs.libuv.org/en/v1.x/handle.html#refcount>.
+
+=head2 unref
+
+    $handle->unref();
+
+The L<unref|http://docs.libuv.org/en/v1.x/handle.html#c.uv_unref>
+method un-references the given handle. References are idempotent, that is, if a
+handle is not referenced, then calling this function again will have no
+effect.
+
+See L<Reference Counting|http://docs.libuv.org/en/v1.x/handle.html#refcount>.
+
 
 =head1 AUTHOR
 
