@@ -1,6 +1,6 @@
 package UV::Poll;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.000008';
 
 use strict;
 use warnings;
@@ -10,28 +10,37 @@ use parent 'UV::Handle';
 
 our @EXPORT_OK = (@UV::Poll::EXPORT_XS,);
 
-sub _new_args {
-    my ($class, $args) = @_;
-    my ($fd, $is_socket);
-    for my $key (qw(fd fh socket single_arg)) {
-        next if !defined($fd = delete $args->{$key});
+sub _after_new {
+    my ($self, $args) = @_;
+    $self->_add_event('poll', $args->{on_poll});
+    my $socket = (exists($args->{socket}) && defined($args->{socket})) ? 1 : 0;
 
-        $is_socket = $key eq "socket";
-        if (CORE::ref($fd) eq 'GLOB' || CORE::ref($fd) =~ /^IO::Socket/) {
-            $fd = fileno($fd);
-            last;
-        }
-        elsif (!CORE::ref($fd) && $fd =~ /\A[0-9]+\z/) {
-            last;
-        }
-        else {
-            $fd = undef;
+    my $fd;
+    for my $key (qw(fd fh socket single_arg)) {
+        if (defined($fd = $args->{$key})) {
+            if (CORE::ref($fd) eq 'GLOB' || CORE::ref($fd) =~ /^IO::Socket/) {
+                $fd = fileno($fd);
+                last;
+            }
+            elsif (!CORE::ref($fd) && $fd =~ /\A[0-9]+\z/) {
+                last;
+            }
+            else {
+                $fd = undef;
+            }
         }
     }
     unless (defined($fd)) {
         Carp::croak("No file or socket descriptor provided");
     }
-    return ($class->SUPER::_new_args($args), $fd, $is_socket);
+
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($fd, $self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
 }
 
 sub start {
@@ -83,6 +92,7 @@ UV::Poll - Poll handles in libuv
   my $poll = UV::Poll->new(
     fd => fileno($handle),
     loop => $loop,
+    on_alloc => sub {say "alloc!"},
     on_close => sub {say "close!"},
     on_poll => sub {say "poll!"},
   );
@@ -92,6 +102,7 @@ UV::Poll - Poll handles in libuv
   my $poll = UV::Poll->new(
     socket => 1,
     fd => fileno($socket),
+    on_alloc => sub {say "alloc!"},
     on_close => sub {say "close!"},
     on_poll => sub {say "poll!"},
   );
@@ -197,11 +208,13 @@ following extra methods available.
 
     my $socket = IO::Socket::INET->new(Type => SOCK_STREAM);
 
-    my $poll = UV::Poll->new(socket => $socket);
+    my $poll = UV::Poll->new(socket => 1, fd => fileno($socket));
     # or another loop
     my $poll = UV::Poll->new(
-        socket => $socket,
+        socket => 1.
+        fd => fileno($socket),
         loop => $some_loop,
+        on_alloc => sub {say "alloc!"},
         on_close => sub {say "close!"},
         on_poll => sub {say "poll!"},
     );
@@ -216,11 +229,6 @@ Then initialization happens with
 L<init|http://docs.libuv.org/en/v1.x/poll.html#c.uv_poll_init> or
 L<init_socket|http://docs.libuv.org/en/v1.x/poll.html#c.uv_poll_init_socket>.
 
-A handle specified by the C<socket> argument is initialised via
-C<uv_poll_init_socket>, a distinction which matters to F<MSWin32>. Code which
-wishes to be portable should remember to use this form so it will work
-correctly on that OS, even if the code works fine on others without it.
-
 B<* Note:> As of libuv v1.2.2: the file descriptor is set to non-blocking mode.
 
 =head2 start
@@ -265,8 +273,6 @@ fine. Doing so will update the events mask that is being watched for.
 B<* Note:> Though C<UV_DISCONNECT> can be set, it is unsupported on AIX and as
 such will not be set on the C<$events> field in the callback.
 
-Returns the C<$poll> instance itself.
-
 =head2 stop
 
     $poll->stop();
