@@ -1,12 +1,26 @@
 package UV::Prepare;
 
-our $VERSION = '1.908_002';
+our $VERSION = '1.000008';
 
 use strict;
 use warnings;
 use Carp ();
+use Exporter qw(import);
 use parent 'UV::Handle';
 
+sub _after_new {
+    my ($self, $args) = @_;
+    $self->_add_event('prepare', $args->{on_prepare});
+
+    my $err = do { #catch
+        local $@;
+        eval { $self->_init($self->{_loop}); 1; }; #try
+        $@;
+    };
+    Carp::croak($err) if $err; # throw
+    return $self;
+}
+
 sub start {
     my $self = shift;
     if (@_) {
@@ -50,6 +64,7 @@ UV::Prepare - Prepare handles in libuv
   my $loop = UV::Loop->new(); # non-default loop
   my $prepare = UV::Prepare->new(
     loop => $loop,
+    on_alloc => sub {say "alloc!"},
     on_close => sub {say "close!"},
     on_prepare => sub {say "prepare!"},
   );
@@ -105,6 +120,7 @@ following extra methods available.
     # Or tell it what loop to initialize against
     my $prepare = UV::Prepare->new(
         loop => $loop,
+        on_alloc => sub {say "alloc!"},
         on_close => sub {say "close!"},
         on_prepare => sub {say "prepare!"},
     );
@@ -129,8 +145,6 @@ L<UV::Loop/"default_loop"> is assumed.
 The L<start|http://docs.libuv.org/en/v1.x/prepare.html#c.uv_prepare_start> method
 starts the handle.
 
-Returns the C<$prepare> instance itself.
-
 =head2 stop
 
     $prepare->stop();
